
//
//  TANUSZipCodeView+HS_XObject.h
//  Created by:  Todd Anthony Nathan
//  Date:        Tue Mar 11 09:45:22 GMT-0600 1997
//
//  Implementation code for the required HS_XObject protocol
//  which TANZipCodeXElement must adhere to.  I put it here
//  to minimize the 'damage' done that class.
///

#import "TANUSZipCodeView.h"
#import "TANUSZipCodeView+HS_XObject.h"
#import <string.h>

@implementation TANUSZipCodeView ( HS_XObject )


+ (id <HS_XObject>)HS_newObjectForElement:(id <HS_Proxy>)xElement
				inZone:(NXZone *)zone
{
    NXRect defaultRect = { {0,0}, {0,0} };

    id theElement = [[self allocFromZone:zone] initFrame:&defaultRect];

    return ( theElement );
}


+ (BOOL)HS_allowsNonSharedData
{
    // Curerntly unused, just return NO
    return ( NO );
}


- (void)HS_releaseForElement:(id <HS_Proxy>)xElement
{
    // Free the unused element
    [self free];
    return;
}


// Define the list of supported properties
// This list should always have a NULL as the last entry
static const char *_TANUSZipCodeViewProperties[] = {
	"lineColor",
	"bkgColor",
	"code",
	NULL
    };
#define TANUSZipCodeView_lineColor	_TANUSZipCodeViewProperties[0]
#define TANUSZipCodeView_bkgColor	_TANUSZipCodeViewProperties[1]
#define TANUSZipCodeView_code	_TANUSZipCodeViewProperties[2]


- (const char **)HS_propertyListForElement:(id <HS_Proxy>)xElement
{
    // Return the statically-defined property list
    return ( _TANUSZipCodeViewProperties );
}


- (BOOL)HS_hasProperty:(NXAtom)property forElement:(id <HS_Proxy>)xElement
{
	// Locate the property from the list, return YES if found.
    int i = 0;
	int	notFound = 1;

    while ( _TANUSZipCodeViewProperties[i] && notFound ) {
		notFound = strcasecmp(property, _TANUSZipCodeViewProperties[i++]);
	}

    return ( notFound? NO : YES );
}


- (BOOL)HS_isPropertyWritable:(NXAtom)property
			forElement:(id <HS_Proxy>)xElement 
{
    return ( YES );
}


- (BOOL)HS_getProperty:(NXAtom)property
			into:(id <HS_Value>)container
			forElement:(id <HS_Proxy>)xElement
{
    if ( !strcasecmp ( property, TANUSZipCodeView_lineColor ) ) {
		[container setColorValue:[self lineColor]];
		return ( YES );
	} else if ( !strcasecmp ( property, TANUSZipCodeView_bkgColor ) ) {
		[container setColorValue:[self bkgColor]];
		return ( YES );
	} else if ( !strcasecmp ( property, TANUSZipCodeView_code ) ) {
		[container setStringValue:[self code]];
		return ( YES );
	}

    return ( NO );
}


- (BOOL)HS_setProperty:(NXAtom)property
		to:(id <HS_Value>)newValue
		forElement:(id <HS_Proxy>)xElement
{
    if ( !strcasecmp ( property, TANUSZipCodeView_lineColor ) ) {
		[self setLineColor:[newValue colorValue]];
		return ( YES );
    } else if ( !strcasecmp ( property, TANUSZipCodeView_bkgColor ) ) {
		[self setBkgColor:[newValue colorValue]];
		return ( YES );
    } else if ( !strcasecmp ( property, TANUSZipCodeView_code ) ) {
		[self setCode:[newValue stringValue]];
		return ( YES );
	}

    return ( NO );
}


@end

